@@ -43,7 +43,7 @@ distinct..data.frame <- function(.df, ..., .keep_all = FALSE) {
 
   } else {
 
-    select_cols <- select_dots_i(.df, ...)
+    select_cols <- select_dots_idx(.df, ...)
 
     .df <- unique(.df, by = select_cols)
 
@@ -58,7 +58,7 @@ distinct..data.frame <- function(.df, ..., .keep_all = FALSE) {
 #' @rdname dt_verb
 #' @inheritParams distinct.
 dt_distinct <- function(.df, ..., .keep_all = FALSE) {
-  deprecate_soft("0.5.2", "tidytable::dt_distinct()", "distinct.()")
+  deprecate_warn("0.5.2", "tidytable::dt_distinct()", "distinct.()")
 
   distinct.(.df, ..., .keep_all = .keep_all)
 }
