@@ -63,7 +63,7 @@ filter..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
 #' @rdname dt_verb
 #' @inheritParams filter.
 dt_filter <- function(.df, ..., .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_filter()", "filter.()")
+  deprecate_warn("0.5.2", "tidytable::dt_filter()", "filter.()")
 
   .by <- check_dot_by(enquo(.by), enquo(by))
 
