@@ -10,7 +10,7 @@ map2. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2.
 dt_map2 <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2()", "map2.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2()", "map2.()")
 
   map2.(.x, .y, .f, ...)
 }
@@ -25,7 +25,7 @@ map2_lgl. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2_lgl.
 dt_map2_lgl <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_lgl()", "map2_lgl.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_lgl()", "map2_lgl.()")
 
   map2_lgl.(.x, .y, .f, ...)
 }
@@ -40,7 +40,7 @@ map2_int. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2_int.
 dt_map2_int <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_int()", "map2_int.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_int()", "map2_int.()")
 
   map2_int.(.x, .y, .f, ...)
 }
@@ -55,7 +55,7 @@ map2_dbl. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2_dbl.
 dt_map2_dbl <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_dbl()", "map2_dbl.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_dbl()", "map2_dbl.()")
 
   map2_dbl.(.x, .y, .f, ...)
 }
@@ -70,7 +70,7 @@ map2_chr. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2_chr.
 dt_map2_chr <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_chr()", "map2_chr.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_chr()", "map2_chr.()")
 
   map2_chr.(.x, .y, .f, ...)
 }
@@ -87,7 +87,7 @@ map2_dfc. <- function(.x, .y, .f, ...) {
 #' @rdname dt_verb
 #' @inheritParams map2_dfc.
 dt_map2_dfc <- function(.x, .y, .f, ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_dfc()", "map2_dfc.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_dfc()", "map2_dfc.()")
 
   map2_dfc.(.x, .y, .f, ...)
 }
@@ -104,7 +104,7 @@ map2_dfr. <- function(.x, .y, .f, ..., .id = NULL) {
 #' @rdname dt_verb
 #' @inheritParams map2_dfr.
 dt_map2_dfr <- function(.x, .y, .f, ..., .id = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_dfr()", "map2_dfr.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_dfr()", "map2_dfr.()")
 
   map2_dfr.(.x, .y, .f, ..., .id = .id)
 }
@@ -117,7 +117,7 @@ map2_df. <- map2_dfr.
 #' @rdname dt_verb
 #' @inheritParams map2_df.
 dt_map2_df <- function(.x, .y, .f, ..., .id = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_map2_df()", "map2_df.()")
+  deprecate_warn("0.5.2", "tidytable::dt_map2_df()", "map2_df.()")
 
   map2_df.(.x, .y, .f, ..., .id = NULL)
 }
