@@ -10,11 +10,11 @@
 #' @param .by Columns to group by
 #' @param .names A glue specification that helps with renaming output columns.
 #' `{.col}` stands for the selected column, and `{.fn}` stands for the name of the function being applied.
-#' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and "`{.col}_{.fn}`"
+#' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and `"{.col}_{.fn}"`
+#' when a list is used for `.fns`.
 #' @param by This argument has been renamed to .by and is deprecated
 #'
 #' @export
-#' @md
 #'
 #' @examples
 #' test_df <- data.table(
@@ -109,7 +109,7 @@ mutate_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
 #' @rdname dt_verb
 #' @inheritParams mutate_across.
 dt_mutate_across <- function(.df, .cols = everything(), .fns, ..., .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_mutate_across()", "mutate_across.()")
+  deprecate_warn("0.5.2", "tidytable::dt_mutate_across()", "mutate_across.()")
 
   .by <- check_dot_by(enquo(.by), enquo(by))
   mutate_across.(.df, .cols = {{ .cols }}, .fns, ..., .by = {{ .by }})
