@@ -56,7 +56,7 @@ rename_with..data.frame <- function(.df, .fn, .cols = everything(), ...) {
 #' @rdname dt_verb
 #' @inheritParams rename_with.
 dt_rename_with <- function(.df, .fn, .cols = everything(), ...) {
-  deprecate_soft("0.5.2", "tidytable::dt_rename_with()", "rename_with.()")
+  deprecate_warn("0.5.2", "tidytable::dt_rename_with()", "rename_with.()")
 
   rename_with.(.df, .fn, .cols = {{ .cols }}, ...)
 }
