@@ -15,7 +15,7 @@
 #'   x = c(1, 2, NA),
 #'   y = c(NA, 1, 2))
 #'
-#' # Using replace_na.() inside mutate()
+#' # Using replace_na.() inside mutate.()
 #' test_df %>%
 #'   mutate.(x = replace_na.(x, 5))
 #'
@@ -32,9 +32,14 @@ replace_na..default <- function(.x, replace = NA) {
   vec_assert(replace, size = 1)
 
   if (class(replace) %in% c("integer", "double", "numeric")) {
+
     nafill(.x, "const", fill = replace)
+
   } else {
-    ifelse.(is.na(.x), replace, .x)
+
+    replace <- vec_cast(replace, vec_ptype(.x))
+
+    .x %|% replace
   }
 }
 
@@ -43,7 +48,7 @@ replace_na..data.frame <- function(.x, replace = list()) {
 
   .x <- as_tidytable(.x)
 
-  stopifnot(is_list(replace))
+  stopifnot(vec_is_list(replace))
 
   if (length(replace) == 0) return(.x)
 
@@ -54,28 +59,18 @@ replace_na..data.frame <- function(.x, replace = list()) {
     .var <- replace_vars[[i]]
 
     .replace_val <- replace[[i]]
-    check_replacement(.replace_val)
 
-    .x[[.var]] <- ifelse.(is.na(.x[[.var]]), .replace_val, .x[[.var]])
+    .x[[.var]] <- replace_na.(.x[[.var]], .replace_val)
   }
 
   .x
 }
 
-check_replacement <- function(x) {
-  n <- length(x)
-  if (n == 1) {
-    return()
-  }
-
-  abort("Replacement values must be of length 1")
-}
-
 #' @export
 #' @rdname dt_verb
 #' @inheritParams replace_na.
 dt_replace_na <- function(.x, replace = NA) {
-  deprecate_soft("0.5.2", "tidytable::dt_replace_na()", "replace_na.()")
+  deprecate_warn("0.5.2", "tidytable::dt_replace_na()", "replace_na.()")
 
   replace_na.(.x, replace)
 }
