@@ -10,11 +10,10 @@
 #' @param .by Columns to group by
 #' @param .names A glue specification that helps with renaming output columns.
 #' `{.col}` stands for the selected column, and `{.fn}` stands for the name of the function being applied.
-#' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and "`{.col}_{.fn}`"
+#' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and `"{.col}_{.fn}"`
 #' when a list is used for `.fns`.
 #' @param by This argument has been renamed to .by and is deprecated
 #'
-#' @md
 #' @export
 #'
 #' @examples
@@ -70,8 +69,6 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
 
   if (!is.list(.fns)) {
 
-    if (!is.null(.names)) summarize_across_warning()
-
     .names <- .names %||% "{.col}"
 
     .col_names <- vec_as_names(
@@ -89,8 +86,6 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
 
   } else {
 
-    summarize_across_warning()
-
     # Make new names
     names_flag <- have_name(.fns)
 
@@ -117,16 +112,3 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
 #' @export
 #' @rdname summarize_across.
 summarise_across. <- summarize_across.
-
-summarize_across_warning <- function() {
-
-  warn(
-    paste(
-      c("As of tidytable v0.5.4, column names generated by summarize_across.() follow",
-        "dplyr summarize(across()) conventions of using suffixes instead of prefixes. This may",
-        "require updates to older versions of your code."),
-      collapse = "\n"),
-    .frequency = "regularly",
-    .frequency_id = "summarize_across_names"
-  )
-}
