@@ -1,8 +1,11 @@
-test_that("dt_distinct() works on all rows", {
+setup(options(lifecycle_verbosity = "quiet"))
+
+test_that("dt_distinct() works on all rows & is deprecated", {
   test_df <- tidytable(a = 1:3, b = 4:6, c = c("a", "a", "b"))
   distinct_df <- test_df %>%
     dt_distinct()
 
+  expect_deprecated(dt_distinct(test_df))
   expect_equal(names(test_df), names(distinct_df))
   expect_equal(test_df, distinct_df)
 })
