@@ -1,10 +1,12 @@
-test_that("dt_ifelse works", {
+test_that("dt_ifelse works & is deprecated", {
 
   df <- tidytable(x = 1:4)
 
   df <- df %>%
     dt_mutate(new_col = dt_ifelse(x > 2L, NA, x - 1L))
 
+  expect_deprecated(dt_mutate(df, new_col = dt_ifelse(x > 2L, NA, x - 1L)))
+
   expect_equal(df$new_col, c(0,1,NA,NA))
 })
 
