@@ -19,6 +19,22 @@ test_that("returns a vec", {
   expect_equal(test_df$y, result_vec)
 })
 
+test_that("numerical selection works with negatives", {
+  test_df <- data.table(x = c(1,2,3), y = c(4,5,6))
+  result_vec <- test_df %>%
+    pull.(-1)
+
+  expect_equal(test_df$y, result_vec)
+})
+
+test_that("numerical selection works with positives", {
+  test_df <- data.table(x = c(1,2,3), y = c(4,5,6))
+  result_vec <- test_df %>%
+    pull.(2)
+
+  expect_equal(test_df$y, result_vec)
+})
+
 test_that("returns a vec with data.frame input", {
   test_df <- data.frame(x = c(1,2,3), y = c(4,5,6))
   result_vec <- test_df %>%
